/*

Copyright (C) 2009 Jaroslav Barton <djaara@djaara.net>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/

#include <QDBusObjectPath>

#include "FingerManagerDevicesModel.h"

/**
 * FingerManagerDevicesModel - data model for combo box.
 */
FingerManagerDevicesModel::FingerManagerDevicesModel(QObject *parent) 
    : QAbstractListModel(parent) 
{
}

/**
 * destructor
 */
FingerManagerDevicesModel::~FingerManagerDevicesModel() 
{
	m_devices.clear();
}

/**
 * setDefault - set default device
 * @param devicePath device object path
 */
void FingerManagerDevicesModel::setDefaultDevice(const QString& devicePath) {
	for (int i = 0; i < m_devices.size(); i++) {
		if (m_devices.at(i).devicePath == devicePath) {
			m_defaultDeviceIndex = i;
			return;
		}
	}
}

/**
 * getDefault - return default device index
 * @return int
 */
int FingerManagerDevicesModel::getDefaultDeviceIndex()  const {
	return m_defaultDeviceIndex;
}

/**
 * addDevice - add new device to model
 * @param devicePath device object path
 * @param deviceName device name
 */
void FingerManagerDevicesModel::addDevice(const QString& devicePath, const QString& deviceName) {
	DeviceModel d;
	d.deviceName = deviceName;
	d.devicePath = devicePath;
	m_devices.push_back(d);
}

/**
 * rowCount - returns number of devices in model 
 * @return int
 */
int FingerManagerDevicesModel::rowCount(const QModelIndex&) const {
	return m_devices.size();
}

/**
 * data - return data for selected row and role
 * @param index row index
 * @param role role
 * @return QVariant
 */
QVariant FingerManagerDevicesModel::data(const QModelIndex& index, int role) const {
	QVariant result;
	if (role == Qt::DisplayRole) {
		result = m_devices.at(index.row()).deviceName;
	}
	return result;
}

/**
 * getDeviceName - return device name
 * @param row row index
 * @return QString
 */
QString FingerManagerDevicesModel::getDeviceName(int row) {
	return m_devices.at(row).deviceName;
}

/**
 * getDevicePath - return device path
 * @param row row index
 * @return QString
 */
QString FingerManagerDevicesModel::getDevicePath(int row) {
	return m_devices.at(row).devicePath;
}

/**
 * getDeviceModel - return device model
 * @param int row index
 * @return DeviceModel
 */
DeviceModel FingerManagerDevicesModel::getDeviceModel(int row) {
	return m_devices.at(row);
}
